<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sq">
<context>
    <name>GrandSearch::BestMatchWidget</name>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/bestmatchwidget.cpp" line="22"/>
        <source>Best match</source>
        <translation>Përkimi më i mirë</translation>
    </message>
</context>
<context>
    <name>GrandSearch::BlackListWidget</name>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/blacklistwidget.cpp" line="26"/>
        <source>Excluded path</source>
        <translation>Shteg i përjashtuar</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/blacklistwidget.cpp" line="37"/>
        <source>Add paths to the exclusion list to prevent searching in them.</source>
        <translation>Shtoni shtigje te lista e përjashtimeve, për të penguar kërkimin në ta.</translation>
    </message>
</context>
<context>
    <name>GrandSearch::CustomWidget</name>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/customwidget.cpp" line="26"/>
        <source>Custom search</source>
        <translation>Kërkim i përshtatur</translation>
    </message>
</context>
<context>
    <name>GrandSearch::DdeGrandSearchDockPlugin</name>
    <message>
        <location filename="../src/grand-search-dock-plugin/ddegrandsearchdockplugin.cpp" line="42"/>
        <location filename="../src/grand-search-dock-plugin/ddegrandsearchdockplugin.cpp" line="85"/>
        <source>Grand Search</source>
        <translation>Kërkim i Madh</translation>
    </message>
    <message>
        <location filename="../src/grand-search-dock-plugin/ddegrandsearchdockplugin.cpp" line="148"/>
        <source>Search settings</source>
        <translation>Rregullime kërkimi</translation>
    </message>
</context>
<context>
    <name>GrandSearch::DeleteDialog</name>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/blacklistview/deletedialog.cpp" line="14"/>
        <source>Do you want to remove the path from the exclusion list?</source>
        <translation>Doni të hiqet shtegu nga lista e përjashtimeve?</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/blacklistview/deletedialog.cpp" line="20"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Anuloje</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/blacklistview/deletedialog.cpp" line="28"/>
        <source>Confirm</source>
        <comment>button</comment>
        <translation>Ripohojeni</translation>
    </message>
</context>
<context>
    <name>GrandSearch::EntranceWidget</name>
    <message>
        <location filename="../src/grand-search/gui/entrance/entrancewidget.cpp" line="225"/>
        <source>Search</source>
        <translation>Kërko</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/entrance/entrancewidget.cpp" line="226"/>
        <source>What would you like to search for?</source>
        <translation>Për çfarë doni të kërkohet?</translation>
    </message>
</context>
<context>
    <name>GrandSearch::EntranceWidgetPrivate</name>
    <message>
        <location filename="../src/grand-search/gui/entrance/entrancewidget.cpp" line="78"/>
        <source>Cut</source>
        <translation>Prije</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/entrance/entrancewidget.cpp" line="82"/>
        <source>Copy</source>
        <translation>Kopjoje</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/entrance/entrancewidget.cpp" line="86"/>
        <source>Paste</source>
        <translation>Ngjite</translation>
    </message>
</context>
<context>
    <name>GrandSearch::GeneralPreviewPlugin</name>
    <message>
        <location filename="../src/grand-search/gui/exhibition/preview/generalpreviewplugin.cpp" line="192"/>
        <source>Location:</source>
        <translation>Vendndodhje:</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/exhibition/preview/generalpreviewplugin.cpp" line="203"/>
        <source>Time modified:</source>
        <translation>Kohë kur u ndryshua:</translation>
    </message>
</context>
<context>
    <name>GrandSearch::GeneralToolBar</name>
    <message>
        <location filename="../src/grand-search/gui/exhibition/preview/generalwidget/generaltoolbar.cpp" line="70"/>
        <source>Open</source>
        <translation>Hap</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/exhibition/preview/generalwidget/generaltoolbar.cpp" line="75"/>
        <source>Open Path</source>
        <translation>Hape Shtegun</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/exhibition/preview/generalwidget/generaltoolbar.cpp" line="80"/>
        <source>Copy Path</source>
        <translation>Kopjoje Shtegun</translation>
    </message>
</context>
<context>
    <name>GrandSearch::GroupWidget</name>
    <message>
        <location filename="../src/grand-search/gui/exhibition/matchresult/groupwidget.cpp" line="244"/>
        <source>More</source>
        <translation>Më tepër</translation>
    </message>
</context>
<context>
    <name>GrandSearch::IndexWidget</name>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/indexwidget.cpp" line="22"/>
        <source>Index</source>
        <translation>Tregues</translation>
    </message>
</context>
<context>
    <name>GrandSearch::MainWindow</name>
    <message>
        <location filename="../src/grand-search/gui/mainwindow.cpp" line="208"/>
        <source>No search results</source>
        <translation>S’ka përfundime kërkimi</translation>
    </message>
</context>
<context>
    <name>GrandSearch::PlanWidget</name>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/planwidget.cpp" line="27"/>
        <source>Search experience program</source>
        <translation>Program përshtypjesh nga kërkimi</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/planwidget.cpp" line="35"/>
        <source>Join search experience program</source>
        <translation>Merrni pjesë te programi i përshtypjeve nga kërkimi</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/planwidget.cpp" line="48"/>
        <source>Joining the search experience program means that you grant and authorize us to collect the information of your device and system, file icons, content and properties, applications and their configurations. If you refuse our collection and use of the aforementioned information, do not join the program.</source>
        <translation>Pjesëmarrja te programi i përshtypjeve nga kërkimi do të thotë se na akordoni leje dhe autorizoni të grumbullojmë të dhëna mbi pajisjen dhe sistemin tuaj, ikona, lëndë dhe veti kartelash, aplikacione dhe formësime të tyre. Nëse e hidhni postë grumbullimin dhe përdorimin prej nesh të të dhënave të përmendura më sipër, mos merrni pjesë te programi.</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/planwidget.cpp" line="57"/>
        <source>To know more about the management of your data, please refer to the UnionTech Software Privacy Policy (</source>
        <translation>Për të ditur më tepër rreth administrimit të të dhënave tuaja, ju lutemi, shihni te Rregulla Privatësie nga UnionTech Software (</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/planwidget.cpp" line="59"/>
        <source>https://www.uniontech.com/agreement/privacy-en</source>
        <translation>https://www.uniontech.com/agreement/privacy-en</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/planwidget.cpp" line="60"/>
        <source>https://www.deepin.org/en/agreement/privacy/</source>
        <translation>https://www.deepin.org/en/agreement/privacy/</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/planwidget.cpp" line="62"/>
        <source>).</source>
        <translation>).</translation>
    </message>
</context>
<context>
    <name>GrandSearch::ScopeWidget</name>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/scopewidget.cpp" line="28"/>
        <source>Search contents</source>
        <translation>Kërko te lëndë</translation>
    </message>
</context>
<context>
    <name>GrandSearch::SearchEngineWidget</name>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/searchenginewidget.cpp" line="31"/>
        <source>Default search engine</source>
        <translation>Motor parazgjedhje kërkimesh</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/searchenginewidget.cpp" line="39"/>
        <source>Search for keywords by the default search engine.</source>
        <translation>Kërkoni për fjalë me motorin parazgjedhje të kërkimeve.</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/searchenginewidget.cpp" line="55"/>
        <source>Default search engine is</source>
        <translation>Motori parazgjedhje i kërkimeve është</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/searchenginewidget.cpp" line="64"/>
        <source>Google</source>
        <translation>Google</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/searchenginewidget.cpp" line="65"/>
        <source>Baidu</source>
        <translation>Baidu</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/searchenginewidget.cpp" line="66"/>
        <source>Bing</source>
        <translation>Bing</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/searchenginewidget.cpp" line="67"/>
        <source>Yahoo</source>
        <translation>Yahoo</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/searchenginewidget.cpp" line="68"/>
        <source>360</source>
        <translation>360</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/searchenginewidget.cpp" line="69"/>
        <source>Sogou</source>
        <translation>Sogou</translation>
    </message>
</context>
<context>
    <name>GrandSearch::StaticTextWorker</name>
    <message>
        <location filename="../src/libgrand-search-daemon/searcher/web/statictextworker.cpp" line="53"/>
        <source>Search for &quot;%1&quot;</source>
        <translation>Kërko për “%1”</translation>
    </message>
</context>
<context>
    <name>GrandSearch::TailerWidget</name>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/tailerwidget.cpp" line="18"/>
        <source>Tailer settings</source>
        <translation>Rregullime Tailer-i</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/tailerwidget.cpp" line="28"/>
        <source>It is displayed at the end of search results for better identification and distinction of items with duplicate names.</source>
        <translation>Shfaqet në fund të përfundimeve të kërkimit, për identifikim dhe ndarje më të mirë të objekteve me emra të përsëdytur.</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/tailerwidget.cpp" line="41"/>
        <source>Parent directory</source>
        <translation>Drejtori mëmë</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/tailerwidget.cpp" line="43"/>
        <source>Time modified</source>
        <translation>Kohë kur është ndryshuar</translation>
    </message>
</context>
<context>
    <name>GrandSearch::audio_preview::AudioPreviewPlugin</name>
    <message>
        <location filename="../src/preview-plugin/audio-preview/audiopreviewplugin.cpp" line="52"/>
        <source>Artist:</source>
        <translation>Artist:</translation>
    </message>
    <message>
        <location filename="../src/preview-plugin/audio-preview/audiopreviewplugin.cpp" line="64"/>
        <source>Album:</source>
        <translation>Album:</translation>
    </message>
    <message>
        <location filename="../src/preview-plugin/audio-preview/audiopreviewplugin.cpp" line="85"/>
        <source>Duration:</source>
        <translation>Kohëzgjatje:</translation>
    </message>
    <message>
        <location filename="../src/preview-plugin/audio-preview/audiopreviewplugin.cpp" line="100"/>
        <source>Type:</source>
        <translation>Lloj:</translation>
    </message>
    <message>
        <location filename="../src/preview-plugin/audio-preview/audiopreviewplugin.cpp" line="112"/>
        <source>Location:</source>
        <translation>Vendndodhje:</translation>
    </message>
    <message>
        <location filename="../src/preview-plugin/audio-preview/audiopreviewplugin.cpp" line="126"/>
        <source>Time modified:</source>
        <translation>Kohë kur u ndryshua:</translation>
    </message>
</context>
<context>
    <name>GrandSearch::image_preview::ImagePreviewPlugin</name>
    <message>
        <location filename="../src/preview-plugin/image-preview/imagepreviewplugin.cpp" line="53"/>
        <source>Dimensions:</source>
        <translation>Përmasa:</translation>
    </message>
    <message>
        <location filename="../src/preview-plugin/image-preview/imagepreviewplugin.cpp" line="69"/>
        <source>Type:</source>
        <translation>Lloj:</translation>
    </message>
    <message>
        <location filename="../src/preview-plugin/image-preview/imagepreviewplugin.cpp" line="84"/>
        <source>Size:</source>
        <translation>Madhësi:</translation>
    </message>
    <message>
        <location filename="../src/preview-plugin/image-preview/imagepreviewplugin.cpp" line="96"/>
        <source>Location:</source>
        <translation>Vendndodhje:</translation>
    </message>
    <message>
        <location filename="../src/preview-plugin/image-preview/imagepreviewplugin.cpp" line="110"/>
        <source>Time modified:</source>
        <translation>Kohë kur u ndryshua:</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/grand-search/gui/datadefine.h" line="24"/>
        <source>Best match</source>
        <translation>Përkimi më i mirë</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/datadefine.h" line="25"/>
        <source>Applications</source>
        <translation>Aplikacione</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/datadefine.h" line="26"/>
        <source>Settings</source>
        <translation>Rregullime</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/datadefine.h" line="27"/>
        <source>Videos</source>
        <translation>Video</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/datadefine.h" line="28"/>
        <source>Music</source>
        <translation>Muzikë</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/datadefine.h" line="29"/>
        <source>Pictures</source>
        <translation>Figura</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/datadefine.h" line="30"/>
        <source>Documents</source>
        <translation>Dokumente</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/datadefine.h" line="31"/>
        <source>Folders</source>
        <translation>Dosje</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/datadefine.h" line="32"/>
        <source>Files</source>
        <translation>Kartela</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/datadefine.h" line="33"/>
        <source>Web</source>
        <translation>Web</translation>
    </message>
    <message>
        <location filename="../src/preview-plugin/video-preview/videopreviewplugin.cpp" line="19"/>
        <source>Dimensions:</source>
        <translation>Përmasa:</translation>
    </message>
    <message>
        <location filename="../src/preview-plugin/video-preview/videopreviewplugin.cpp" line="20"/>
        <source>Type:</source>
        <translation>Lloj:</translation>
    </message>
    <message>
        <location filename="../src/preview-plugin/video-preview/videopreviewplugin.cpp" line="21"/>
        <source>Size:</source>
        <translation>Madhësi:</translation>
    </message>
    <message>
        <location filename="../src/preview-plugin/video-preview/videopreviewplugin.cpp" line="22"/>
        <source>Duration:</source>
        <translation>Kohëzgjatje:</translation>
    </message>
    <message>
        <location filename="../src/preview-plugin/video-preview/videopreviewplugin.cpp" line="23"/>
        <source>Location:</source>
        <translation>Vendndodhje:</translation>
    </message>
    <message>
        <location filename="../src/preview-plugin/video-preview/videopreviewplugin.cpp" line="24"/>
        <source>Time modified:</source>
        <translation>Kohë kur u ndryshua:</translation>
    </message>
    <message>
        <location filename="../src/libgrand-search-daemon/searcher/file/filesearchutils.cpp" line="203"/>
        <source>modified</source>
        <translation>ndryshuar më</translation>
    </message>
</context>
</TS>
